@@ -19,13 +19,14 @@
  * USA
  *
  * --------------------------------------------------------------------------
- * $Id: RouteBuilderComponent.java 19784 2010-04-28 17:05:13Z alitokmen $
+ * $Id: RouteBuilderComponent.java 19805 2010-05-02 11:27:19Z alitokmen $
  * --------------------------------------------------------------------------
  */
 package org.ow2.jonas.camel.component;
 
 import java.io.File;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 import java.util.logging.Level;
 import java.util.logging.Logger;
@@ -154,18 +155,11 @@ public abstract class RouteBuilderComponent extends RouteBuilder {
 
             // Start a new Camel context for the application
             this.camelContextName = this.camelService.startNewContext();
-
-            // Add JNDI resolver to the JMS component
             CamelContext camelContext = this.camelService.getCamelContext(this.camelContextName);
-            JmsComponent jms = camelContext.getComponent("jms", JmsComponent.class);
-            ConnectionFactory connectionFactory = (ConnectionFactory) new InitialContext().lookup("JCF");
-            jms.setConnectionFactory(connectionFactory);
-            JndiDestinationResolver jndiDestinationResolver = new JndiDestinationResolver();
-            jndiDestinationResolver.setCache(true);
-            jms.setDestinationResolver(jndiDestinationResolver);
 
             // Add registry entries
             RegistryInjector injector = new RegistryInjector(this.registryReplacements);
+            this.configureCamelComponents(camelContext, injector.getRegistryFilesContent());
             injector.injectRegistry(this.camelService, this.camelContextName);
 
             // Add the routes in the camel context
@@ -200,6 +194,30 @@ public abstract class RouteBuilderComponent extends RouteBuilder {
         }
     }
 
+    /**
+     * Configure CAMEL components, called just before registry injection.<br/>
+     * <br/>
+     * By default, the <code>jms</code> component is configured to use the
+     * <code>JCF</code> connection factory on JNDI.<br/>
+     * <br/>
+     * You can override this method to configure other components, for example
+     * <code>jdbc</code>.
+     * 
+     * @param camelContext CAMEL context.
+     * @param registryFilesContent Actual contents of the CAMEL registry files
+     *        (with all variables replaced).
+     */
+    protected void configureCamelComponents(final CamelContext camelContext, final List<String> registryFilesContent)
+        throws Exception {
+        // Add JNDI resolver to the JMS component
+        JmsComponent jms = camelContext.getComponent("jms", JmsComponent.class);
+        ConnectionFactory connectionFactory = (ConnectionFactory) new InitialContext().lookup("JCF");
+        jms.setConnectionFactory(connectionFactory);
+        JndiDestinationResolver jndiDestinationResolver = new JndiDestinationResolver();
+        jndiDestinationResolver.setCache(true);
+        jms.setDestinationResolver(jndiDestinationResolver);
+    }
+
     /**
      * Configures the Camel context with the tracer.
      */
